{% ckan_extends %}

{% block view_form_filters %}
    {% if data.view_type != "json_viewer" %}
        {% snippet 'package/snippets/view_form_filters.html', resource=resource, resource_view=resource_view %}
    {% endif %}
{% endblock %}
